"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stripAnsi = require("strip-ansi");
/** mocks stdout or stderr */
function mock(std) {
    const debug = require('debug')(std);
    const orig = process[std].write;
    let writes = [];
    function _debug(msg) {
        if (!debug.enabled)
            return;
        // remap writer to allow it to send to debug
        const prev = process[std].write;
        process[std].write = orig;
        debug(msg);
        process[std].write = prev;
    }
    return {
        stripColor: true,
        print: false,
        start() {
            writes = [];
            process[std].write = (data) => {
                _debug(data);
                writes.push(bufToString(data));
                if (this.print)
                    orig.apply(process[std], data);
                return true;
            };
        },
        stop() {
            process[std].write = orig;
        },
        get output() {
            let o = this.stripColor ? writes.map(stripAnsi) : writes;
            return o.join('');
        },
    };
}
exports.stdout = mock('stdout');
exports.stderr = mock('stderr');
function bufToString(b) {
    if (typeof b === 'string')
        return b;
    return b.toString('utf8');
}
